@@ -8,7 +8,7 @@ bin2int <- function(binary){
   
   # round
   binary <- round(binary)
-
+  
   # determine length of binary representation
   length <- dim(binary)[2]
   
@@ -19,4 +19,4 @@ bin2int <- function(binary){
 #' @describeIn bin2int individual Binary to Integer
 
 b2i <- function(binary)
-  packBits(as.raw(rev(c(rep(0, 32-length(binary) ), binary))), 'integer')
+  packBits(as.raw(c(rep(0, 32-length(binary) ), binary)), 'integer')
